@@ -27,8 +27,10 @@ void
 do_output (int s, glibtop_response *resp, off_t offset,
 	   size_t data_size, const void *data)
 {
-	glibtop_debug ("Really writing %zu bytes at offset %lu.",
+#ifdef DEBUG
+	fprintf (stderr, "Really writing %d bytes at offset %lu.\n",
 		 sizeof (glibtop_response), offset);
+#endif
 
 	resp->offset = offset;
 	resp->data_size = data_size;
@@ -42,7 +44,9 @@ do_output (int s, glibtop_response *resp, off_t offset,
 	}
 
 	if (resp->data_size) {
-		glibtop_debug ("Writing %lu bytes of data.", resp->data_size);
+#ifdef DEBUG
+		fprintf (stderr, "Writing %d bytes of data.\n", resp->data_size);
+#endif
 
 		if (s == 0) {
 			if (write (1, data, resp->data_size) < 0)
@@ -84,8 +88,10 @@ do_read (int s, void *ptr, size_t total_size)
 		tmp_ptr += nread;
 		ptr = tmp_ptr;
 
-		glibtop_debug ("READ (%d): %zu - %zu - %zu",
+#ifdef DEBUG
+		fprintf (stderr, "READ (%d): %d - %d - %d\n",
 			 nread, already_read, remaining, total_size);
+#endif
 	}
 
 	return already_read;
