@@ -22,14 +22,40 @@
 #include <config.h>
 #include "daemon.h"
 
+static glibtop _glibtop_global_server;
+glibtop *glibtop_global_server = &_glibtop_global_server;
+
 #include <glibtop.h>
 #include <glibtop/union.h>
 #include <glibtop/sysdeps.h>
-#include <glibtop/error.h>
-#include <glibtop/machine.h>
 
 #include <sys/utsname.h>
 
+const unsigned long glibtop_server_features =
+GLIBTOP_SUID_CPU +
+GLIBTOP_SUID_MEM +
+GLIBTOP_SUID_SWAP +
+GLIBTOP_SUID_UPTIME +
+GLIBTOP_SUID_LOADAVG +
+GLIBTOP_SUID_SHM_LIMITS +
+GLIBTOP_SUID_MSG_LIMITS +
+GLIBTOP_SUID_SEM_LIMITS +
+GLIBTOP_SUID_PROCLIST +
+GLIBTOP_SUID_PROC_STATE +
+GLIBTOP_SUID_PROC_UID +
+GLIBTOP_SUID_PROC_MEM +
+GLIBTOP_SUID_PROC_TIME +
+GLIBTOP_SUID_PROC_SIGNAL +
+GLIBTOP_SUID_PROC_KERNEL +
+GLIBTOP_SUID_PROC_SEGMENT +
+GLIBTOP_SUID_PROC_ARGS +
+GLIBTOP_SUID_PROC_MAP +
+GLIBTOP_SUID_NETLOAD +
+GLIBTOP_SUID_NETLIST +
+GLIBTOP_SUID_PROC_WD +
+GLIBTOP_SUID_PROC_AFFINITY +
+GLIBTOP_SUID_PPP;
+
 #include <fcntl.h>
 #include <locale.h>
 
@@ -44,8 +70,6 @@ main(int argc, char *argv[])
 	uid = getuid (); euid = geteuid ();
 	gid = getgid (); egid = getegid ();
 
-	glibtop_debug ("uid=%d euid=%d gid=%d egid=%d", getuid(), geteuid(), getgid(), getegid());
-
 	if (uname (&uts) < 0) _exit (1);
 
 #ifdef _AIX
@@ -76,18 +100,12 @@ main(int argc, char *argv[])
 	}
 #endif
 
-	glibtop_machine_new (glibtop_global_server);
-
 	glibtop_init_p (glibtop_global_server, 0, 0);
 
-	glibtop_debug ("uid=%d euid=%d gid=%d egid=%d", getuid(), geteuid(), getgid(), getegid());
-
 	if (setreuid (euid, uid)) _exit (1);
 
 	if (setregid (egid, gid)) _exit (1);
 
-	glibtop_debug ("uid=%d euid=%d gid=%d egid=%d", getuid(), geteuid(), getgid(), getegid());
-
 	/* !!! END OF SUID ROOT PART !!! */
 
 	handle_slave_connection (0, 0);
