@@ -26,66 +26,24 @@
 
 #include <glibtop/error.h>
 
-enum MESSAGE_LEVEL {
-	MESSAGE_DEBUG,
-	MESSAGE_WARNING,
-	MESSAGE_ERROR
-};
-
 #define DEFAULT_NAME	"LibGTop-Server"
 
 /* Prints error message and exits. */
 
 static void
-print_message (const glibtop *server, int message_level, const char *format, int error, va_list args)
+print_server_name (const glibtop *server)
 {
-	const char *level;
-	GString* message;
-
-	message = g_string_new(NULL);
-
-	g_string_printf(message, "%s", (server && server->name ? server->name : DEFAULT_NAME));
-
-	if (server && server->pid) {
-		g_string_append_printf(message, "(c=%u/s=%u)", getpid(), server->pid);
-	}
-	else {
-		g_string_append_printf(message, "(c=%u)", getpid());
-	}
-
-	switch (message_level) {
-	case MESSAGE_DEBUG:
-		level = "DEBUG";
-		break;
-	case MESSAGE_WARNING:
-		level = "WARNING";
-		break;
-	case MESSAGE_ERROR:
-		level = "ERROR";
-		break;
-	default:
-		level = "UNKNOWN";
-	}
-
-	g_string_append_printf(message, ": [%s] ", level);
-
-	g_string_append_vprintf(message, format, args);
-
-	if (error) {
-		g_string_append_printf(message, ": %s", g_strerror(error));
-	}
-
-	g_string_append_c(message, '\n');
-
-	fputs(message->str, stderr);
-
-	g_string_free(message, TRUE);
+	fprintf (stderr, "%s: ", server && server->name
+		 ? server->name
+		 : DEFAULT_NAME);
 }
 
 void
 glibtop_error_vr (glibtop *server, const char *format, va_list args)
 {
-	print_message (server, MESSAGE_ERROR, format, 0, args);
+	print_server_name (server);
+	vfprintf (stderr, format, args);
+	fputc('\n', stderr);
 
 #ifdef LIBGTOP_ENABLE_DEBUG
 	abort ();
@@ -97,7 +55,9 @@ glibtop_error_vr (glibtop *server, const char *format, va_list args)
 void
 glibtop_error_io_vr (glibtop *server, const char *format, int error, va_list args)
 {
-	print_message (server, MESSAGE_ERROR, format, error, args);
+	print_server_name (server);
+	vfprintf (stderr, format, args);
+	fprintf (stderr, ": %s\n", g_strerror (error));
 
 #ifdef LIBGTOP_ENABLE_DEBUG
 	abort ();
@@ -109,7 +69,9 @@ glibtop_error_io_vr (glibtop *server, const char *format, int error, va_list arg
 void
 glibtop_warn_vr (glibtop *server, const char *format, va_list args)
 {
-	print_message (server, MESSAGE_WARNING, format, 0, args);
+	print_server_name (server);
+	vfprintf (stderr, format, args);
+	fputc('\n', stderr);
 
 #ifdef LIBGTOP_FATAL_WARNINGS
 	abort ();
@@ -119,7 +81,9 @@ glibtop_warn_vr (glibtop *server, const char *format, va_list args)
 void
 glibtop_warn_io_vr (glibtop *server, const char *format, int error, va_list args)
 {
-	print_message (server, MESSAGE_WARNING, format, error, args);
+	print_server_name (server);
+	vfprintf (stderr, format, args);
+	fprintf (stderr, ": %s\n", g_strerror (error));
 
 #ifdef LIBGTOP_FATAL_WARNINGS
 	abort ();
@@ -169,23 +133,6 @@ glibtop_warn_io_r (glibtop *server, const char *format, ...)
 }
 
 
-void
-glibtop_debug_vr (glibtop *server, const char *format, va_list args)
-{
-	print_message (server, MESSAGE_DEBUG, format, 0, args);
-}
-
-void
-glibtop_debug_r_real (glibtop *server, const char *format, ...)
-{
-	va_list args;
-
-	va_start (args, format);
-	glibtop_debug_vr (server, format, args);
-	va_end (args);
-}
-
-
 void
 glibtop_error (const char *format, ...)
 {
