@@ -15,17 +15,17 @@
 
    You should have received a copy of the GNU General Public License
    along with LibGTop; see the file COPYING. If not, write to the
-   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef __GLIBTOP_MACHINE_H__
 #define __GLIBTOP_MACHINE_H__
 
 #include <sys/param.h>
+#include <sys/sched.h>
 #include <nlist.h>
 #include <kvm.h>
-#include <sys/dkstat.h>
 #include <time.h>
 #include <sys/user.h>
 #include <sys/types.h>
