@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU General Public License
    along with LibGTop; see the file COPYING. If not, write to the
-   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
@@ -41,6 +41,10 @@
 #include <sys/ucred.h>
 #include <sys/sysctl.h>
 
+/* XXX until uvm gets cleaned up */
+#include <sys/mutex.h>
+typedef int boolean_t;
+
 #undef _KERNEL
 #define _UVM_UVM_AMAP_I_H_ 1
 #define _UVM_UVM_MAP_I_H_ 1
@@ -276,11 +280,11 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
 
 		mentry->perm   = (guint64) 0;
 
-		if (entry->protection & VM_PROT_READ)
+		if (entry->protection & PROT_READ)
 			mentry->perm |= GLIBTOP_MAP_PERM_READ;
-		if (entry->protection & VM_PROT_WRITE)
+		if (entry->protection & PROT_WRITE)
 			mentry->perm |= GLIBTOP_MAP_PERM_WRITE;
-		if (entry->protection & VM_PROT_EXECUTE)
+		if (entry->protection & PROT_EXECUTE)
 			mentry->perm |= GLIBTOP_MAP_PERM_EXECUTE;
 	}
 
