@@ -25,10 +25,7 @@
 #include <glibtop/cpu.h>
 #include <glibtop/open.h>
 #include <glibtop/init_hooks.h>
-#include <glibtop/machine.h>
 
-#include <fcntl.h>
-#include <kvm.h>
 
 /* !!! THIS FUNCTION RUNS SUID ROOT - CHANGE WITH CAUTION !!! */
 
@@ -59,27 +56,27 @@ glibtop_open_p (glibtop *server, const char *program_name,
 		const unsigned flags)
 {
 	char errbuf[_POSIX2_LINE_MAX];
-#ifdef LIBGTOP_ENABLE_DEBUG
+#ifdef DEBUG
 	fprintf (stderr, "DEBUG (%d): glibtop_open_p ()\n", getpid ());
 #endif
 
 	/* !!! WE ARE ROOT HERE - CHANGE WITH CAUTION !!! */
-	server->machine->uid = getuid ();
-	server->machine->euid = geteuid ();
-	server->machine->gid = getgid ();
-	server->machine->egid = getegid ();
+	server->machine.uid = getuid ();
+	server->machine.euid = geteuid ();
+	server->machine.gid = getgid ();
+	server->machine.egid = getegid ();
 	/* Setup machine-specific data */
-	server->machine->kd = kvm_openfiles (NULL, NULL, NULL, KVM_NO_FILES, errbuf);
+	server->machine.kd = kvm_openfiles (NULL, NULL, NULL, O_RDONLY, errbuf);
 
-	if (server->machine->kd == NULL)
-		glibtop_error_io_r (server, "kvm_openfiles");
+	if (server->machine.kd == NULL)
+		glibtop_error_io_r (server, "kvm_open");
 
 	/* Drop priviledges. */
 
-	if (setreuid (server->machine->euid, server->machine->uid))
+	if (setreuid (server->machine.euid, server->machine.uid))
 		_exit (1);
 
-	if (setregid (server->machine->egid, server->machine->gid))
+	if (setregid (server->machine.egid, server->machine.gid))
 		_exit (1);
 
 	/* !!! END OF SUID ROOT PART !!! */
